@@ -176,7 +176,11 @@ file exists, otherwise nil."
 	       w3m-current-coding-system))
 	    (set-buffer-modified-p nil))
 	  (setq w3m-bookmark-buffer-file-name w3m-bookmark-file)
-	  (set-visited-file-modtime (w3m-bookmark-file-modtime))
+	  (set-visited-file-modtime (or (w3m-bookmark-file-modtime)
+					;; No bookmark file.
+					(with-temp-buffer
+					  ;; 0 in Emacs; (0 . 0) in XEmacs
+					  (visited-file-modtime))))
 	  (buffer-enable-undo))
 	(current-buffer)))))
 
@@ -551,7 +555,7 @@ Format as (list (\"Group name\" . (\"Entry URL\" . \"Entry name\")* )* )."
 (defvar w3m-bookmark-make-item-xmas
   (and (equal "Japanese" w3m-language) (featurep 'xemacs)))
 
-(defsubst w3m-bookmark-make-item (item)
+(defun w3m-bookmark-make-item (item)
   (if w3m-bookmark-make-item-xmas
       (concat item "%_ ")
     item))
